#[repr(u8)]pub enum Res0Dz {
RES0_DZ_NO = 0,
RES0_DZ_YES = 1,
}Variants
RES0_DZ_NO = 0
No exact infinite result is defined for an operation on finite operands.
RES0_DZ_YES = 1
An exact infinite result is defined for an operation on finite operands.
Implementations