#[repr(u8)]pub enum Res1Dz {
RES1_DZ_NO = 0,
RES1_DZ_YES = 1,
}Variants
RES1_DZ_NO = 0
No exact infinite result is defined for an operation on finite operands.
RES1_DZ_YES = 1
An exact infinite result is defined for an operation on finite operands.
Implementations