#[repr(u8)]pub enum Res2Dz {
RES2_DZ_NO = 0,
RES2_DZ_YES = 1,
}Variants
RES2_DZ_NO = 0
No exact infinite result is defined for an operation on finite operands.
RES2_DZ_YES = 1
An exact infinite result is defined for an operation on finite operands.
Implementations