#[repr(u8)]pub enum Res3Dz {
RES3_DZ_NO = 0,
RES3_DZ_YES = 1,
}Variants
RES3_DZ_NO = 0
No exact infinite result is defined for an operation on finite operands.
RES3_DZ_YES = 1
An exact infinite result is defined for an operation on finite operands.
Implementations